Trait Row
pub trait Row:
Unpin
+ Send
+ Sync
+ 'static {
type Database: Database<Row = Self>;
// Required method
fn columns(&self) -> &[<Self::Database as Database>::Column];
// Provided methods
fn is_empty(&self) -> bool { ... }
fn len(&self) -> usize { ... }
fn column<I>(&self, index: I) -> &<Self::Database as Database>::Column
where I: ColumnIndex<Self> { ... }
fn try_column<I>(
&self,
index: I,
) -> Result<&<Self::Database as Database>::Column, Error>
where I: ColumnIndex<Self> { ... }
fn get<'a, T, I>(&'a self, index: I) -> T
where I: ColumnIndex<Self>,
T: TryGetable<'a, Self::Database> { ... }
fn try_get<'a, T, I>(&'a self, index: I) -> Result<T, Error>
where I: ColumnIndex<Self>,
T: TryGetable<'a, Self::Database> { ... }
}Expand description
Represents a single row from the database.
Required Associated Types
Required Methods
Provided Methods
fn column<I>(&self, index: I) -> &<Self::Database as Database>::Columnwhere
I: ColumnIndex<Self>,
fn column<I>(&self, index: I) -> &<Self::Database as Database>::Columnwhere
I: ColumnIndex<Self>,
Gets the column information at index.
A string index can be used to access a column by name and a usize index
can be used to access a column by position.
Panics
Panics if index is out of bounds.
See try_column for a non-panicking version.
fn try_column<I>(
&self,
index: I,
) -> Result<&<Self::Database as Database>::Column, Error>where
I: ColumnIndex<Self>,
fn try_column<I>(
&self,
index: I,
) -> Result<&<Self::Database as Database>::Column, Error>where
I: ColumnIndex<Self>,
Gets the column information at index or None if out of bounds.
fn get<'a, T, I>(&'a self, index: I) -> T
fn get<'a, T, I>(&'a self, index: I) -> T
Index into the database row and decode a single value.
A string index can be used to access a column by name and a usize index
can be used to access a column by position.
Panics
Panics if the column does not exist or its value cannot be decoded into the requested type.
See try_get for a non-panicking version.
fn try_get<'a, T, I>(&'a self, index: I) -> Result<T, Error>
fn try_get<'a, T, I>(&'a self, index: I) -> Result<T, Error>
Index into the database row and decode a single value.
A string index can be used to access a column by name and a usize index
can be used to access a column by position.
Errors
ColumnNotFoundif the column by the given name was not found.ColumnIndexOutOfBoundsif theusizeindex was greater than the number of columns in the row.ColumnDecodeif the value could not be decoded into the requested type.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.